# CoreX logging - loki

This package provides an implementation of the CoreX logging interface for loki.

## Installation
~~~bash
pip install corex-logging-loki
~~~

## Usage
~~~python
from corex_logging_loki.handler import LokiHandler
handler = LokiHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
